@@ -19,7 +19,6 @@ class Transport(object):
     :param session: A :py:class:`request.Session()` object (optional)
 
     """
-    supports_async = False
 
     def __init__(self, cache=None, timeout=300, operation_timeout=None,
                  session=None):
@@ -76,7 +75,7 @@ class Transport(object):
             else:
                 log_message = response.content
                 if isinstance(log_message, bytes):
-                    log_message = log_message.decode('utf-8')
+                    log_message = log_message.decode(response.encoding or 'utf-8')
 
             self.logger.debug(
                 "HTTP Response from %s (status: %d):\n%s",
@@ -123,18 +122,19 @@ class Transport(object):
             return fh.read()
 
     def _load_remote_data(self, url):
+        self.logger.debug("Loading remote data from: %s", url)
         response = self.session.get(url, timeout=self.load_timeout)
         response.raise_for_status()
         return response.content
 
     @contextmanager
-    def _options(self, timeout=None):
+    def settings(self, timeout=None):
         """Context manager to temporarily overrule options.
 
         Example::
 
-            client = zeep.Client('foo.wsdl')
-            with client.options(timeout=10):
+            transport = zeep.Transport()
+            with transport.settings(timeout=10):
                 client.service.fast_call()
 
         :param timeout: Set the timeout for POST/GET operations (not used for
