@@ -5,6 +5,7 @@ from lxml import etree
 from pretend import stub
 
 from zeep import asyncio, exceptions
+from zeep.cache import InMemoryCache
 
 
 @pytest.mark.requests
@@ -24,6 +25,29 @@ def test_load(event_loop):
         assert result == b'x'
 
 
+@pytest.mark.requests
+def test_load_cache(event_loop):
+    cache = InMemoryCache()
+    transport = asyncio.AsyncTransport(loop=event_loop, cache=cache)
+
+    with aioresponses() as m:
+        m.get('http://tests.python-zeep.org/test.xml', body='x')
+        result = transport.load('http://tests.python-zeep.org/test.xml')
+        assert result == b'x'
+
+    assert cache.get('http://tests.python-zeep.org/test.xml') == b'x'
+
+
+def test_cache_checks_type():
+    cache = InMemoryCache()
+
+    async def foo():
+        pass
+
+    with pytest.raises(TypeError):
+        cache.add('x', foo())
+
+
 @pytest.mark.requests
 @pytest.mark.asyncio
 async def test_post(event_loop):
