@@ -131,6 +131,9 @@ class TestDateTime:
         value = value.astimezone(pytz.timezone('Europe/Amsterdam'))
         assert instance.xmlvalue(value) == '2016-03-04T22:14:42+01:00'
 
+        assert instance.xmlvalue('2016-03-04T22:14:42+01:00') == '2016-03-04T22:14:42+01:00'
+        assert instance.xmlvalue('2016-03-04') == '2016-03-04'
+
     def test_pythonvalue(self):
         instance = builtins.DateTime()
         value = datetime.datetime(2016, 3, 4, 21, 14, 42)
@@ -139,6 +142,9 @@ class TestDateTime:
         value = datetime.datetime(2016, 3, 4, 21, 14, 42, 123456)
         assert instance.pythonvalue('2016-03-04T21:14:42.123456') == value
 
+        value = datetime.datetime(2016, 3, 4, 0, 0, 0)
+        assert instance.pythonvalue('2016-03-04') == value
+
     def test_pythonvalue_invalid(self):
         instance = builtins.DateTime()
         with pytest.raises(ValueError):
